@@ -39,5 +39,11 @@ def _move_to_this_dir():
 
 
 if __name__ == '__main__':
-    env_data = json.loads(sys.argv[1])
+    inp = sys.argv[1]
+    
+    # fix a windows issue not removing the single qoute ...
+    if inp[0] == "'":
+        inp = inp[1:-1]
+
+    env_data = json.loads(inp)
     create_app_with_resource(env_data)
